
local defaults = {
	profile = {
		MainMenuBarScale = 1,
		MainMenuBarGryphonsHidden = false,
		
		MicroMenuHidden = false,
		MicroMenuLocked = false,
		MicroMenuScale = 1,
		MicroMenuPoint = {
			XOffset = 0,
			YOffset = 0,
			Point = "CENTER",
			RelatedPoint = "CENTER",
			RelatedTo = "WorldFrame"
		},

		StanceBarHidden = false,
		StanceBarLocked = false,
		StanceBarScale = 1,
		StanceBarPoint = {
			XOffset = 0,
			YOffset = 0,
			Point = "CENTER",
			RelatedPoint = "CENTER",
			RelatedTo = "WorldFrame"
		},
		
		BagsBarHidden = false,
		BagsBarLocked = false,
		BagsBarScale = 1,
		BagsBarPoint = {
			XOffset = 0,
			YOffset = 0,
			Point = "CENTER",
			RelatedPoint = "CENTER",
			RelatedTo = "WorldFrame"
		},

		PetBarHidden = false,
		PetBarLocked = false,
		PetBarScale = 1,
		PetBarPoint = {
			XOffset = 0,
			YOffset = 0,
			Point = "CENTER",
			RelatedPoint = "CENTER",
			RelatedTo = "WorldFrame"
		}
	}
}

local CombatLock = false
local VehicleLock = false

MiniMainBar = LibStub("AceAddon-3.0"):NewAddon("MiniMainBar", "AceConsole-3.0", "AceHook-3.0", "AceEvent-3.0")

function MiniMainBar:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("MiniMainBarDB", defaults, "Default")

	self.db.RegisterCallback(self, "OnProfileChanged", "UpdateFromProfile")
	self.db.RegisterCallback(self, "OnProfileCopied", "UpdateFromProfile")
	self.db.RegisterCallback(self, "OnProfileReset", "UpdateFromProfile")

	self:SecureHook("UIParent_ManageFramePositions", MiniMainBar.UpdateGUI)
	
	MiniMainBar:InitOptions()
	MiniMainBar:InitGUI()
	
	return true
end

function MiniMainBar:UpdateFromProfile()

end

function MiniMainBar:InitGUI()
	if InCombatLockdown() then
		VehicleLock = true
		return
	else
		VehicleLock = false
	end
	
	MiniMainBar:InitMainMenuBar()
	MiniMainBar:InitMicroMenu()
	MiniMainBar:InitBagsBar()
	MiniMainBar:InitStanceBar()
	MiniMainBar:InitPetBar()
end

function MiniMainBar:UpdateGUI()
	if InCombatLockdown() then 
		CombatLock = true
		return
	else
		CombatLock = false
	end	
	
	MiniMainBar:UpdateMainMenuBar()
	MiniMainBar:UpdateMicroMenu()
	MiniMainBar:UpdateBagsBar()
	MiniMainBar:UpdateStanceBar()
	MiniMainBar:UpdatePetBar()
end

function MiniMainBar:InitMainMenuBar()
	--if InCombatLockdown() or UnitHasVehicleUI("player") then return end
	if InCombatLockdown() or UnitUsingVehicle("player") then return end
	
	-- Main Menu bar elements to be hidden
	MainMenuBarPageNumber:Hide()
	ActionBarUpButton:Hide()
	ActionBarDownButton:Hide()
	MainMenuXPBarTexture2:Hide()
	MainMenuXPBarTexture3:Hide()
	MainMenuBarTexture2:Hide()
	MainMenuBarTexture3:Hide()
	MainMenuMaxLevelBar2:Hide()
	MainMenuMaxLevelBar3:Hide()

	MainMenuXPBarTexture0:SetPoint("BOTTOM", "MainMenuExpBar", "BOTTOM", -128, 2)
	MainMenuXPBarTexture1:SetPoint("BOTTOM", "MainMenuExpBar", "BOTTOM", 128, 3)
	MainMenuMaxLevelBar0:SetPoint("BOTTOM", "MainMenuBarMaxLevelBar", "TOP", -128, 0)
	MainMenuBarTexture0:SetPoint("BOTTOM", "MainMenuBarArtFrame", "BOTTOM", -128, 0)
	MainMenuBarTexture1:SetPoint("BOTTOM", "MainMenuBarArtFrame", "BOTTOM", 128, 0)
	MainMenuBarLeftEndCap:SetPoint("BOTTOM", "MainMenuBarArtFrame", "BOTTOM", -290, 0)
	MainMenuBarRightEndCap:SetPoint("BOTTOM", "MainMenuBarArtFrame", "BOTTOM", 287, 0)
	
	-- Clear XP/Rep bar textures
	ReputationWatchBarTexture2:SetTexture("")
	ReputationWatchBarTexture3:SetTexture("")
	ReputationXPBarTexture2:SetTexture("")
	ReputationXPBarTexture3:SetTexture("")
	
	-- Resize MainMenuBar
	MainMenuBar:SetWidth(512)
	MainMenuExpBar:SetWidth(512)
	ReputationWatchBar:SetWidth(512)
	MainMenuBarMaxLevelBar:SetWidth(512)
	ReputationWatchStatusBar:SetWidth(512)
	
	MiniMainBar:HideGryphons(self.db.profile.MainMenuBarGryphonsHidden)
	MiniMainBar:ScaleMainMenuBar(self.db.profile.MainMenuBarScale)
end

function MiniMainBar:UpdateMainMenuBar()
	--if InCombatLockdown() or UnitHasVehicleUI("player") then return end
	if InCombatLockdown() or UnitUsingVehicle("player") then return end

	if MultiBarBottomRight:IsShown() then
		local YOffset = 0
		if MultiBarBottomLeft:IsShown() then
			YOffset = 42
		end

		MultiBarBottomRight:ClearAllPoints();
		MultiBarBottomRight:SetPoint("BOTTOMLEFT", MultiBarBottomLeft, "BOTTOMLEFT", 0, YOffset);
	end
end

-- Scale the Main bar
function MiniMainBar:ScaleMainMenuBar(Scale)
	MainMenuBar:SetScale(Scale)
	MultiBarBottomLeft:SetScale(Scale)
	MultiBarBottomRight:SetScale(Scale)
	MultiBarRight:SetScale(Scale)
	MultiBarLeft:SetScale(Scale)
end

-- Hide or show the gryphon endcaps
function MiniMainBar:HideGryphons(IsHidden)
	if (IsHidden) then
		MainMenuBarLeftEndCap:Hide();
		MainMenuBarRightEndCap:Hide();
    else
		MainMenuBarLeftEndCap:Show();
		MainMenuBarRightEndCap:Show();	
	end
end